@@ -13,6 +13,16 @@
 
 typedef volatile atomic_flag ezt_spinlock;
 
+#ifdef __NVCOMPILER
+/* When compiling with NVCC, the compiler complains of the atomic_flag type and we need to cast variables to void*
+ * However, other compilers (eg clang) do complain when casting to void*
+ * -> We need two different cast depending on the compiler
+ */
+#define ATOMIC_FLAG_CAST(ptr) (void*)ptr
+#else
+#define ATOMIC_FLAG_CAST(ptr) ptr
+#endif
+
 #define ezt_spin_unlocked ATOMIC_FLAG_INIT
 
 #if defined(__x86_64__)
@@ -27,13 +37,13 @@ typedef volatile atomic_flag ezt_spinlock;
 
 static void ezt_spin_init(ezt_spinlock *l) __attribute__((unused));
 static void ezt_spin_init(ezt_spinlock *l) {
-  atomic_flag_clear(l);
+  atomic_flag_clear(ATOMIC_FLAG_CAST(l));
 }
 
 static void ezt_spin_lock(ezt_spinlock *l) __attribute__((unused));
 static void ezt_spin_lock(ezt_spinlock *l) {
   uint64_t count=0;
-  while(atomic_flag_test_and_set(l)) {
+  while(atomic_flag_test_and_set(ATOMIC_FLAG_CAST(l))) {
     PAUSE;
     if(count++ > 100)
       // we've been waiting for a while, let other thread work
@@ -46,7 +56,7 @@ static void ezt_spin_lock(ezt_spinlock *l) {
 
 static void ezt_spin_unlock(ezt_spinlock *l) __attribute__((unused));
 static void ezt_spin_unlock(ezt_spinlock *l) {
-  atomic_flag_clear(l);
+  atomic_flag_clear(ATOMIC_FLAG_CAST(l));
 }
 
 
